@@ -1,6 +1,6 @@
-__version__ = "1.0.9-1"
+__version__ = "1.1.1"
 __author__ = "Palo Alto Cortex Xpanse"
 __license__ = "ISC"
 __maintainer__ = "Palo Alto Cortex Xpanse"
 __email__ = "help@expanseinc.com"
-__status__ = "Development"
+__status__ = "Production"
